<?php

namespace Drupal\vkoembed\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Configure settings.
 */
class SettingsForm extends ConfigFormBase {

  /**
   * Config settings.
   *
   * @var string
   */
  const SETTINGS = 'vkoembed.api.setting';

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'vk_api_admin_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      static::SETTINGS,
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config(static::SETTINGS);
    $schema = \Drupal::service('config.typed')->getDefinition(static::SETTINGS);

    $fieldName = 'vk_key';
    $definition = $schema['mapping'][$fieldName] ?: [];
    $label = $definition['label'] ?? '';

    $form[$fieldName] = [
      '#type' => 'textfield',
      '#size' => 100,
      '#title' => $this->t($label),
      '#default_value' => $config->get($fieldName),
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    // Retrieve the configuration.
    $this->config(static::SETTINGS)
      // Set the submitted configuration setting.
      ->set('vk_key', $form_state->getValue('vk_key'))
      ->save();

    parent::submitForm($form, $form_state);
  }

}